==> react-view-router-2.1.7.tgz: package/es/history/memory.js <==
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import { Action, HistoryType } from './types';
import { createEvents, createPath, createKey, parsePath, readOnly, clamp, allowTx } from './utils';
/**
 * A memory history stores locations in memory. This is useful in stateful
 * environments where there is no web browser, such as node tests or React
 * Native.
 *
 * @see https://github.com/ReactTraining/history/tree/master/docs/api-reference.md#memoryhistory
 */

export function createMemoryHref(to) {
  return typeof to === 'string' ? to : createPath(to);
}
/**
  * Memory history stores the current location in memory. It is designed for use
  * in stateful non-browser environments like tests and React Native.
  *
  * @see https://github.com/ReactTraining/history/tree/master/docs/api-reference.md#creatememoryhistory
  */

export function createMemoryHistory(options = {}) {
  let {
    initialEntries = ['/'],
    initialIndex
  } = options;
  let entries = initialEntries.map(entry => {
    let location = readOnly(_objectSpread({
      pathname: '/',
      search: '',
      hash: '',
      state: null,
      key: createKey()
    }, typeof entry === 'string' ? parsePath(entry) : entry));
    return location;
  });
  let index = clamp(initialIndex == null ? entries.length - 1 : initialIndex, 0, entries.length - 1);
  let type = HistoryType.memory;
  let action = Action.Push;
  let location = entries[index];
  let listeners = createEvents();
  let blockers = createEvents();

  const createHref = to => createMemoryHref(to);

  function getNextLocation(to, state = null) {
    let {
      pathname = '/',
      search = '',
      hash = ''
    } = location;
    return readOnly(_objectSpread(_objectSpread({
      pathname,
      search,
      hash
    }, typeof to === 'string' ? parsePath(to) : to), {}, {
      state,
      key: createKey()
    }));
  }

  function applyTx(nextAction, nextLocation, nextIndex, payload) {
    action = nextAction;
    location = nextLocation;
    index = nextIndex;
    listeners.call({
      action,
      location,
      index
    }, payload);
  }

  function getIndex(delta) {
    let ret = index;

    if (delta) {
      index = clamp(index + delta, 0, entries.length - 1);
    }

    return ret;
  }

  function push(to, state) {
    let nextAction = Action.Push;
    let nextLocation = getNextLocation(to, state);

    const callback = (ok, payload) => {
      if (!ok) return;
      index = getIndex(typeof to !== 'string' ? to.delta : undefined) + 1;
      entries.splice(index, entries.length, nextLocation);
      applyTx(nextAction, nextLocation, index, payload);
    };

    if (allowTx(blockers, nextAction, nextLocation, index, getIndex(typeof to !== 'string' ? to.delta : undefined) + 1, callback)) {
      callback(true, to);
    }
  }

  function replace(to, state) {
    let nextAction = Action.Replace;
    let nextLocation = getNextLocation(to, state);

    const callback = (ok, payload) => {
      if (!ok) return;

      if (typeof to !== 'string' && to.delta) {
        index = clamp(index + to.delta, 0, entries.length - 1);
      }

      entries[index] = nextLocation;
      applyTx(nextAction, nextLocation, index, payload);
    };

    if (allowTx(blockers, nextAction, nextLocation, index, getIndex(typeof to !== 'string' ? to.delta : undefined), callback)) {
      callback(true, to);
    }
  }

  function go(delta) {
    let nextIndex = clamp(index + delta, 0, entries.length - 1);
    let nextAction = Action.Pop;
    let nextLocation = entries[nextIndex];

    const callback = (ok, payload) => {
      if (!ok) return;
      index = nextIndex;
      applyTx(nextAction, nextLocation, index, payload);
    };

    if (allowTx(blockers, nextAction, nextLocation, index, getIndex(delta), callback)) {
      callback(true);
    }
  }

  let history = {
    get extra() {
      return options.extra;
    },

    get type() {
      return type;
    },

    get action() {
      return action;
    },

    get location() {
      return location;
    },

    get index() {
      return index;
    },

    get length() {
      return entries.length;
    },

    get realtimeLocation() {
      return location;
    },

    createHref,

    getIndexAndLocation() {
      return [index, location];
    },

    push,
    replace,

    replaceState(state) {
      return location.state = state;
    },

    go,

    back() {
      go(-1);
    },

    forward() {
      go(1);
    },

    listen(listener) {
      return listeners.push(listener);
    },

    block(blocker) {
      return blockers.push(blocker);
    }

  };
  return history;
}

==> react-view-router-2.1.9.tgz: package/es/history/memory.js <==
function ownKeys(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
function _defineProperty(obj, key, value) { key = _toPropertyKey(key); if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
function _toPropertyKey(arg) { var key = _toPrimitive(arg, "string"); return typeof key === "symbol" ? key : String(key); }
function _toPrimitive(input, hint) { if (typeof input !== "object" || input === null) return input; var prim = input[Symbol.toPrimitive]; if (prim !== undefined) { var res = prim.call(input, hint || "default"); if (typeof res !== "object") return res; throw new TypeError("@@toPrimitive must return a primitive value."); } return (hint === "string" ? String : Number)(input); }
import { Action, HistoryType } from './types';
import { createEvents, createPath, createKey, parsePath, freeze, clamp, allowTx } from './utils';
/**
 * A memory history stores locations in memory. This is useful in stateful
 * environments where there is no web browser, such as node tests or React
 * Native.
 *
 * @see https://github.com/ReactTraining/history/tree/master/docs/api-reference.md#memoryhistory
 */

/**
 * A user-supplied object that describes a location. Used when providing
 * entries to `createMemoryHistory` via its `initialEntries` option.
 */

export function createMemoryHref(to) {
  return typeof to === 'string' ? to : createPath(to);
}

/**
  * Memory history stores the current location in memory. It is designed for use
  * in stateful non-browser environments like tests and React Native.
  *
  * @see https://github.com/ReactTraining/history/tree/master/docs/api-reference.md#creatememoryhistory
  */
export function createMemoryHistory(options = {}) {
  let {
    initialEntries = ['/'],
    initialIndex
  } = options;
  let entries = initialEntries.map(entry => {
    let location = freeze(_objectSpread({
      pathname: '/',
      search: '',
      hash: '',
      state: null,
      key: createKey()
    }, typeof entry === 'string' ? parsePath(entry) : entry));
    return location;
  });
  let index = clamp(initialIndex == null ? entries.length - 1 : initialIndex, 0, entries.length - 1);
  let type = HistoryType.memory;
  let action = Action.Push;
  let location = entries[index];
  let listeners = createEvents();
  let blockers = createEvents();
  const createHref = to => createMemoryHref(to);
  function getNextLocation(to, state = null) {
    let {
      pathname = '/',
      search = '',
      hash = ''
    } = location;
    return freeze(_objectSpread(_objectSpread({
      pathname,
      search,
      hash
    }, typeof to === 'string' ? parsePath(to) : to), {}, {
      state,
      key: createKey()
    }));
  }
  function applyTx(nextAction, nextLocation, nextIndex, payload) {
    action = nextAction;
    location = nextLocation;
    index = nextIndex;
    listeners.call({
      action,
      location,
      index
    }, payload);
  }
  function getIndex(delta) {
    let ret = index;
    if (delta) {
      index = clamp(index + delta, 0, entries.length - 1);
    }
    return ret;
  }
  function push(to, state) {
    let nextAction = Action.Push;
    let nextLocation = getNextLocation(to, state);
    const callback = (ok, payload) => {
      if (!ok) return;
      index = getIndex(typeof to !== 'string' ? to.delta : undefined) + 1;
      entries.splice(index, entries.length, nextLocation);
      applyTx(nextAction, nextLocation, index, payload);
    };
    if (allowTx(blockers, nextAction, nextLocation, index, getIndex(typeof to !== 'string' ? to.delta : undefined) + 1, callback)) {
      callback(true, to);
    }
  }
  function replace(to, state) {
    let nextAction = Action.Replace;
    let nextLocation = getNextLocation(to, state);
    const callback = (ok, payload) => {
      if (!ok) return;
      if (typeof to !== 'string' && to.delta) {
        index = clamp(index + to.delta, 0, entries.length - 1);
      }
      entries[index] = nextLocation;
      applyTx(nextAction, nextLocation, index, payload);
    };
    if (allowTx(blockers, nextAction, nextLocation, index, getIndex(typeof to !== 'string' ? to.delta : undefined), callback)) {
      callback(true, to);
    }
  }
  function go(delta) {
    let nextIndex = clamp(index + delta, 0, entries.length - 1);
    let nextAction = Action.Pop;
    let nextLocation = entries[nextIndex];
    const callback = (ok, payload) => {
      if (!ok) return;
      index = nextIndex;
      applyTx(nextAction, nextLocation, index, payload);
    };
    if (allowTx(blockers, nextAction, nextLocation, index, getIndex(delta), callback)) {
      callback(true);
    }
  }
  let history = {
    get extra() {
      return options.extra;
    },
    get type() {
      return type;
    },
    get action() {
      return action;
    },
    get location() {
      return location;
    },
    get index() {
      return index;
    },
    get length() {
      return entries.length;
    },
    get realtimeLocation() {
      return location;
    },
    createHref,
    getIndexAndLocation() {
      return [index, location];
    },
    push,
    replace,
    replaceState(state) {
      return location.state = state;
    },
    refresh() {
      return [index, location];
    },
    go,
    back() {
      go(-1);
    },
    forward() {
      go(1);
    },
    listen(listener) {
      return listeners.push(listener);
    },
    block(blocker) {
      return blockers.push(blocker);
    }
  };
  return history;
}
